package provide GEOplot 1.0

# THIS procedure reads in the option file

proc ReadSI { UDFno X Ya Yb Yc Yd Ye Yf } {
   global ExDa pgmOPTS gOA SIeV0 SIeV1

   upvar $X   pX
   upvar $Ya  sL
   upvar $Yb  sH
   upvar $Yc  mD
   upvar $Yd  mT
   upvar $Ye  mE
   upvar $Yf  sR

# CHECK if we even need to read this data set
                                                                                
   set KeY   $pgmOPTS(K.SI)
   if { [string length $KeY] == 0 } { return 0 }

# ESTABLISH a beginning and ending time over which to get the data

   set BegT $pgmOPTS(BegT)
   set EndT $pgmOPTS(EndT)
   set eY   $pgmOPTS(EndYr)
   set eD   $pgmOPTS(EndDy)

# Establish the sensors and units to get

   set nS [expr [llength $pgmOPTS(S.SI)] - 1]
   for { set I 0 } { $I <= $nS } { incr I } {
      set S($I)  [lindex $pgmOPTS(S.SI) $I]
      set U($I)  [lindex $pgmOPTS(U.SI) $I]
      set iD($I) [lindex $pgmOPTS(I.SI) $I]
      set nU($I) [llength $U($I)]
   }
  
   set Ver $UDFno

# GET the data

   set N 0
   set More -1
   while { $More < 0 } {
      for {set J 0 } { $J <= $nS } { incr J } {
         if { $J == $nS } { set FwD 1 } else { set FwD 0 }
         set EoF [ReadUDF $KeY $UDFno 0 $S($J) 0 $FwD 0]
         for {set K 0 } { $K < $nU($J) } { incr K } {
            set UniT [lindex $U($J) $K]
            set UiD  [lindex $iD($J) $K]
            upvar 0 A$S($J)$UiD Data
            ConvertToUnits $KeY $Ver 0 $UniT Data SENSOR
         }
         if { $N == 0 } {
            upvar 0 SIeV$S($J) eV
            ConvertToUnits $KeY $Ver 0 $pgmOPTS(eV.SI) eV SCAN 
         }
      }     

      set yB $ExDa(0,BYR)
      set dB $ExDa(0,BDY)
      set mB $ExDa(0,BMSEC)
      set yE $ExDa(0,EYR)
      set dE $ExDa(0,EDY)
      set mE $ExDa(0,EMSEC)
      set curT [list $yB $dB $mB 0]
      if [string match EOF $EoF] { break }
      if { $N == 0 } { 
         set pgmOPTS(DMSPTm) $curT 
         set pgmOPTS(nSI) $ExDa(0,NSMP)
         if { [info exists SIeV1] && [info exist SIev1] } { SimConv }
      }

      set Tm [TUtimeConv $pgmOPTS(baseT) $curT 0 pgmOPTS(Base)]
      TUgridInfo 0 gOA gRET $Tm 0.0

      set More [TUtimeCmp 0 $yE $dE $mE $eY $eD $EndT]
      if { $gRET(0) < 0 } { continue }

      set pX($N) $Tm
      set nP [llength $pgmOPTS(SIdP)]
      set nD $ExDa(0,NSMP)
      if $pgmOPTS(SIusesMo) { MomDMSP A1DF A0DF SIeV1 SIeV0 $nD I MoM } 
      for { set I 0 } { $I < $nP } { incr I } {
         switch -exact -- [lindex $pgmOPTS(SIdP) $I] {
            0 { set sH($N) [SumIt $nD A0EF] }
            1 { set sL($N) [SumIt $nD A1EF] }
            2 { set mE($N) $MoM(AeV)} 
            3 { set sR($N) [SimIt A1EF A0EF $MoM(AeV)] }
            4 { set mD($N) $MoM(Den)} 
            5 { set mT($N) $MoM(TmP)} 
         } 
      }
      incr N
      set More [TUtimeCmp 0 $yE $dE $mE $eY $eD $EndT]
   }

   return $N
}
